import { ParserPlugin } from "@babel/parser";
import { JSXElement } from "@babel/types";
/** Options passed to `analyze` */
export interface AnalyzeOptions {
    /** List of Babel plugins needed to parse your code */
    babelPlugins?: ParserPlugin[];
    /** Which JSX components should we scan */
    components?: string[];
    /** Which directory should we scan (defaults to current working directory) */
    directory?: string;
    /** Array of file globs (defaults to all .js, .jsx, .tsx files) */
    files?: string[];
    /** Ignore files specified in the .gitignore file (defaults to true) */
    gitignore?: boolean;
    /** Array of file globs to ignore */
    ignore?: string[];
    /** Async callback called before scanning each new file */
    onFile?: (filename: string) => Promise<void>;
    /** Which JSX prop should we scan for (e.g. `id` or `variant=primary`) */
    prop?: string;
    /** Use relative paths instead of absolute paths */
    relativePaths?: boolean;
}
/** A location in source code */
export interface SourceLocation {
    line: number;
    column: number;
}
/** Information about a parse error */
export interface ErrorInfo {
    message: string;
    pos: number;
    loc: SourceLocation;
    missingPlugin: string[];
}
/** Information about a line where a prop was used */
export interface LineInfo {
    propCode: string;
    prettyCode: string;
    startLoc: SourceLocation;
    endLoc: SourceLocation;
    filename: string;
}
export declare type PropUsage = Record<string, Record<string, number>>;
export declare type LineUsage = Record<string, Record<string, LineInfo[]>>;
export declare type ComponentUsage = Record<string, number>;
export interface Analysis {
    filenames: string[];
    componentTotal: number;
    componentUsageTotal: number;
    componentUsage: ComponentUsage;
    propUsage: PropUsage;
    lineUsage: LineUsage;
    errors: Record<string, ErrorInfo>;
    suggestedPlugins: string[];
    elapsedTime: number;
    directory: string;
}
/**
 * Return a Promise with the JSX usage analysis of a project
 *
 * This function can easily return several megabytes of data. Parsing every
 * single JS/TS file in a project can take a while. Please be patient. The
 * `onFile` callbacks are async. Parsing each file is not an async action and
 * may block for a couple seconds if the file is large. You can insert a "sleep"
 * command into the `onFile` callback if you would like to return control
 * briefly.
 */
export declare function analyze({ babelPlugins, components, directory, files, gitignore, ignore, onFile, prop, relativePaths, }: AnalyzeOptions): Promise<Analysis>;
interface ParseOptions {
    typescript?: boolean;
    babelPlugins?: ParserPlugin[];
    onlyComponents?: string[];
    onComponent?: (options: {
        componentName: string;
        node: JSXElement;
    }) => void;
}
export declare function parse(code: string, options?: ParseOptions): void;
export {};
